pub struct HwiService<Message, Id = ()>{
pub devices: Arc<Mutex<BTreeMap<String, SigningDevice<Message, Id>>>>,
/* private fields */
}Fields
devices: Arc<Mutex<BTreeMap<String, SigningDevice<Message, Id>>>>Implementations
Sourceimpl<Message, Id> HwiService<Message, Id>
impl<Message, Id> HwiService<Message, Id>
pub fn new(network: Network, rt: Option<Handle>) -> Self
pub fn list(&self) -> BTreeMap<String, SigningDevice<Message, Id>>
Sourcepub fn set_bitbox_noise_config(&self, noise_config: Arc<dyn NoiseConfig>)
pub fn set_bitbox_noise_config(&self, noise_config: Arc<dyn NoiseConfig>)
Set the BitBox02 pairing configuration. The NoiseConfigData contains the app’s private key and public keys of all paired devices, so a single config works for all BitBox02 devices.
Sourcepub fn clear_bitbox_noise_config(&self)
pub fn clear_bitbox_noise_config(&self)
Clear the BitBox02 pairing configuration.
pub fn listen(&self, sender: Sender<Message>, shutdown: Arc<AtomicBool>)